@@ -2,8 +2,8 @@
  **
  ** sngrep - SIP Messages flow viewer
  **
- ** Copyright (C) 2013-2017 Ivan Alonso (Kaian)
- ** Copyright (C) 2013-2017 Irontec SL. All rights reserved.
+ ** Copyright (C) 2013-2018 Ivan Alonso (Kaian)
+ ** Copyright (C) 2013-2018 Irontec SL. All rights reserved.
  **
  ** This program is free software: you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -71,6 +71,11 @@ capture_init(size_t limit, bool rtp_capture, bool rotate)
         capture_cfg.storage = CAPTURE_STORAGE_DISK;
     }
 
+#if defined(WITH_GNUTLS) || defined(WITH_OPENSSL)
+    // Parse TLS Server setting
+    capture_cfg.tlsserver = address_from_str(setting_get_value(SETTING_CAPTURE_TLSSERVER));
+#endif
+
     // Initialize calls lock
     pthread_mutexattr_t attr;
     pthread_mutexattr_init(&attr);
@@ -159,6 +164,7 @@ int
 capture_offline(const char *infile, const char *outfile)
 {
     capture_info_t *capinfo;
+    FILE *fstdin;
 
     // Error text (in case of file open error)
     char errbuf[PCAP_ERRBUF_SIZE];
@@ -172,6 +178,7 @@ capture_offline(const char *infile, const char *outfile)
     // Check if file is standard input
     if (strlen(infile) == 1 && *infile == '-') {
         infile = "/dev/stdin";
+        fstdin = freopen("/dev/tty", "r", stdin);
     }
 
     // Set capture input file
@@ -385,7 +392,7 @@ capture_packet_reasm_ip(capture_info_t *capinfo, const struct pcap_pkthdr *heade
     frame_t *frame;
     uint32_t len_data = 0;
     //! Link + Extra header size
-    int8_t link_hl = capinfo->link_hl;
+    uint16_t link_hl = capinfo->link_hl;
 
     // Skip VLAN header if present
     if (capinfo->link == DLT_EN10MB) {
@@ -404,7 +411,24 @@ capture_packet_reasm_ip(capture_info_t *capinfo, const struct pcap_pkthdr *heade
     }
 #endif
 
+    // Skip NFLOG header if present
+    if (capinfo->link == DLT_NFLOG) {
+        // Parse NFLOG TLV headers
+        while (link_hl + 8 <= *caplen) {
+            nflog_tlv_t *tlv = (nflog_tlv_t *) (packet + link_hl);
 
+            if (!tlv) break;
+
+            if (tlv->tlv_type == NFULA_PAYLOAD) {
+                link_hl += 4;
+                break;
+            }
+
+            if (tlv->tlv_length >= 4) {
+                link_hl += ((tlv->tlv_length + 3) & ~3); /* next TLV aligned to 4B */
+            }
+        }
+    }
 
     // Get IP header
     ip4 = (struct ip *) (packet + link_hl);
@@ -783,8 +807,10 @@ capture_close()
     while ((capinfo = vector_iterator_next(&it))) {
         //Close PCAP file
         if (capinfo->handle) {
-            pcap_breakloop(capinfo->handle);
-            pthread_join(capinfo->capture_t, NULL);
+            if (capinfo->running) {
+                pcap_breakloop(capinfo->handle);
+                pthread_join(capinfo->capture_t, NULL);
+            }
         }
     }
 
@@ -818,7 +844,6 @@ capture_thread(void *info)
 
     // Parse available packets
     pcap_loop(capinfo->handle, -1, parse_packet, (u_char *) capinfo);
-    pcap_close(capinfo->handle);
     capinfo->running = false;
 }
 
@@ -974,6 +999,18 @@ capture_set_keyfile(const char *keyfile)
     capture_cfg.keyfile = keyfile;
 }
 
+address_t
+capture_tls_server()
+{
+    return capture_cfg.tlsserver;
+}
+
+int
+capture_sources_count()
+{
+    return vector_count(capture_cfg.sources);
+}
+
 char *
 capture_last_error()
 {
@@ -1059,6 +1096,8 @@ datalink_size(int datalink)
             return 21;
         case DLT_ENC:
             return 12;
+        case DLT_NFLOG:
+            return 4;
 #ifdef DLT_LINUX_SLL
         case DLT_LINUX_SLL:
             return 16;
