@@ -2,8 +2,8 @@
  **
  ** sngrep - SIP Messages flow viewer
  **
- ** Copyright (C) 2013-2017 Ivan Alonso (Kaian)
- ** Copyright (C) 2013-2017 Irontec SL. All rights reserved.
+ ** Copyright (C) 2013-2018 Ivan Alonso (Kaian)
+ ** Copyright (C) 2013-2018 Irontec SL. All rights reserved.
  **
  ** This program is free software: you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -82,7 +82,6 @@ P_hash(const char *digest, unsigned char *dest, int dlen, unsigned char *secret,
 {
     unsigned char hmac[48];
     uint32_t hlen;
-    HMAC_CTX hm;
     const EVP_MD *md = EVP_get_digestbyname(digest);
     uint32_t tmpslen;
     unsigned char tmpseed[slen];
@@ -95,6 +94,8 @@ P_hash(const char *digest, unsigned char *dest, int dlen, unsigned char *secret,
 
     // Calculate enough data to fill destination
     while (pending > 0) {
+#if OPENSSL_VERSION_NUMBER < 0x10100000L
+        HMAC_CTX hm;
         HMAC_Init(&hm, secret, sslen, md);
         HMAC_Update(&hm, tmpseed, tmpslen);
         HMAC_Final(&hm, tmpseed, &tmpslen);
@@ -104,12 +105,25 @@ P_hash(const char *digest, unsigned char *dest, int dlen, unsigned char *secret,
         HMAC_Update(&hm, seed, slen);
         HMAC_Final(&hm, hmac, &hlen);
 
+        HMAC_cleanup(&hm);
+#else
+        HMAC_CTX *hm = HMAC_CTX_new();
+        HMAC_Init_ex(hm, secret, sslen, md, NULL);
+        HMAC_Update(hm, tmpseed, tmpslen);
+        HMAC_Final(hm, tmpseed, &tmpslen);
+
+        HMAC_Init_ex(hm, secret, sslen, md, NULL);
+        HMAC_Update(hm, tmpseed, tmpslen);
+        HMAC_Update(hm, seed, slen);
+        HMAC_Final(hm, hmac, &hlen);
+
+        HMAC_CTX_free(hm);
+#endif
         hlen = (hlen > pending) ? pending : hlen;
         memcpy(out, hmac, hlen);
         out += hlen;
         pending -= hlen;
     }
-    HMAC_cleanup(&hm);
 
     return hlen;
 }
@@ -190,6 +204,8 @@ tls_connection_create(struct in_addr caddr, uint16_t cport, struct in_addr saddr
         return NULL;
 
     conn->server_private_key = SSL_get_privatekey(conn->ssl);
+    conn->client_cipher_ctx = EVP_CIPHER_CTX_new();
+    conn->server_cipher_ctx = EVP_CIPHER_CTX_new();
 
     // Add this connection to the list
     conn->next = connections;
@@ -216,6 +232,8 @@ tls_connection_destroy(struct SSLConnection *conn)
     }
 
     // Deallocate connection memory
+    EVP_CIPHER_CTX_free(conn->client_cipher_ctx);
+    EVP_CIPHER_CTX_free(conn->server_cipher_ctx);
     SSL_CTX_free(conn->ssl_ctx);
     SSL_free(conn->ssl);
     sng_free(conn);
@@ -299,6 +317,7 @@ tls_process_segment(packet_t *packet, struct tcphdr *tcp)
     struct in_addr ip_src, ip_dst;
     uint16_t sport = packet->src.port;
     uint16_t dport = packet->dst.port;
+    address_t tlsserver = capture_tls_server();
 
     // Convert addresses
     inet_pton(AF_INET, packet->src.ip, &ip_src);
@@ -349,8 +368,16 @@ tls_process_segment(packet_t *packet, struct tcphdr *tcp)
         }
     } else {
         if (tcp->th_flags & TH_SYN & ~TH_ACK) {
-            // New connection, store it status and leave
-            tls_connection_create(ip_src, sport, ip_dst, dport);
+            // Only create new connections whose destination is tlsserver
+            if (tlsserver.port) {
+                if (addressport_equals(tlsserver, packet->dst)) {
+                    // New connection, store it status and leave
+                    tls_connection_create(ip_src, sport, ip_dst, dport);
+                }
+            } else {
+                // New connection, store it status and leave
+                tls_connection_create(ip_src, sport, ip_dst, dport);
+            }
         }
     }
 
@@ -377,33 +404,32 @@ tls_process_record_ssl2(struct SSLConnection *conn, const uint8_t *payload,
                    const int len, uint8_t **out, uint32_t *outl)
 {
     int record_len_len;
-    uint16 record_len16;
-    uint24 record_len24;
+    uint32_t record_len;
     uint8_t record_type;
     const opaque *fragment;
     int flen;
 
     // No record data here!
     if (len == 0)
-        return 0;
+        return 1;
 
     // Record header length
     record_len_len = (payload[0] & 0x80) ? 2 : 3;
 
     // Two bytes SSLv2 record length field
     if (record_len_len == 2) {
-        record_len16.x[0] = (payload[0] & 0x7f) << 8;
-        record_len16.x[1] = (payload[1]);
+        record_len = (payload[0] & 0x7f) << 8;
+        record_len += (payload[1]);
         record_type = payload[2];
         fragment = payload + 3;
-        flen = UINT16_INT(record_len16) - 1 /* record type */;
+        flen = record_len - 1 /* record type */;
     } else {
-        record_len24.x[0] = (payload[0] & 0x3f) << 8;
-        record_len24.x[1] = payload[1];
-        record_len24.x[2] = payload[2];
+        record_len = (payload[0] & 0x3f) << 8;
+        record_len += payload[1];
+        record_len += payload[2];
         record_type = payload[3];
         fragment = payload + 4;
-        flen = UINT24_INT(record_len24) - 1 /* record type */;
+        flen = record_len - 1 /* record type */;
     }
 
     // We only handle Client Hello handshake SSLv2 records
@@ -450,7 +476,7 @@ tls_process_record(struct SSLConnection *conn, const uint8_t *payload,
 
     // No record data here!
     if (len == 0)
-        return 0;
+        return 1;
 
     // Get Record data
     record = (struct TLSPlaintext *) payload;
@@ -469,8 +495,14 @@ tls_process_record(struct SSLConnection *conn, const uint8_t *payload,
                 break;
             case change_cipher_spec:
                 // From now on, this connection will be encrypted using MasterSecret
-                if (conn->client_cipher_ctx.cipher && conn->server_cipher_ctx.cipher)
+#if OPENSSL_VERSION_NUMBER < 0x10100000L
+                if (conn->client_cipher_ctx->cipher && conn->server_cipher_ctx->cipher)
                     conn->encrypted = 1;
+#else
+                if (EVP_CIPHER_CTX_get_cipher_data(conn->client_cipher_ctx) &&
+                    EVP_CIPHER_CTX_get_cipher_data(conn->server_cipher_ctx))
+                    conn->encrypted = 1;
+#endif
                 break;
             case application_data:
                 if (conn->encrypted) {
@@ -479,7 +511,7 @@ tls_process_record(struct SSLConnection *conn, const uint8_t *payload,
                 }
                 break;
             default:
-                break;
+                return 1;
         }
     }
 
@@ -556,10 +588,17 @@ tls_process_record_handshake(struct SSLConnection *conn, const opaque *fragment,
                 // Decrypt PreMasterKey
                 clientkeyex = (struct ClientKeyExchange *) body;
 
+#if OPENSSL_VERSION_NUMBER < 0x10100000L
                 RSA_private_decrypt(UINT16_INT(clientkeyex->length),
                                     (const unsigned char *) &clientkeyex->exchange_keys,
                                     (unsigned char *) &conn->pre_master_secret,
                                     conn->server_private_key->pkey.rsa, RSA_PKCS1_PADDING);
+#else
+                RSA_private_decrypt(UINT16_INT(clientkeyex->length),
+                                    (const unsigned char *) &clientkeyex->exchange_keys,
+                                    (unsigned char *) &conn->pre_master_secret,
+                                    EVP_PKEY_get0_RSA(conn->server_private_key), RSA_PKCS1_PADDING);
+#endif
 
                 tls_debug_print_hex("client_random", &conn->client_random, 32);
                 tls_debug_print_hex("server_random", &conn->server_random, 32);
@@ -605,13 +644,13 @@ tls_process_record_handshake(struct SSLConnection *conn, const opaque *fragment,
                 sng_free(seed);
 
                 // Create Client decoder
-                EVP_CIPHER_CTX_init(&conn->client_cipher_ctx);
-                EVP_CipherInit(&conn->client_cipher_ctx, conn->ciph,
+                EVP_CIPHER_CTX_init(conn->client_cipher_ctx);
+                EVP_CipherInit(conn->client_cipher_ctx, conn->ciph,
                                conn->key_material.client_write_key, conn->key_material.client_write_IV,
                                0);
 
-                EVP_CIPHER_CTX_init(&conn->server_cipher_ctx);
-                EVP_CipherInit(&conn->server_cipher_ctx, conn->ciph,
+                EVP_CIPHER_CTX_init(conn->server_cipher_ctx);
+                EVP_CipherInit(conn->server_cipher_ctx, conn->ciph,
                                conn->key_material.server_write_key, conn->key_material.server_write_IV,
                                0);
 
@@ -647,9 +686,9 @@ tls_process_record_data(struct SSLConnection *conn, const opaque *fragment,
     tls_debug_print_hex("Ciphertext", fragment, len);
 
     if (conn->direction == 0) {
-        evp = &conn->client_cipher_ctx;
+        evp = conn->client_cipher_ctx;
     } else {
-        evp = &conn->server_cipher_ctx;
+        evp = conn->server_cipher_ctx;
     }
 
     // TLS 1.1 and later extract explicit IV
