@@ -2,8 +2,8 @@
  **
  ** sngrep - SIP Messages flow viewer
  **
- ** Copyright (C) 2013-2017 Ivan Alonso (Kaian)
- ** Copyright (C) 2013-2017 Irontec SL. All rights reserved.
+ ** Copyright (C) 2013-2018 Ivan Alonso (Kaian)
+ ** Copyright (C) 2013-2018 Irontec SL. All rights reserved.
  **
  ** This program is free software: you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -238,8 +238,8 @@ struct SSLConnection {
         uint8_t server_write_IV[16];
     } key_material;
 
-    EVP_CIPHER_CTX client_cipher_ctx;
-    EVP_CIPHER_CTX server_cipher_ctx;
+    EVP_CIPHER_CTX *client_cipher_ctx;
+    EVP_CIPHER_CTX *server_cipher_ctx;
 
     struct SSLConnection *next;
 };
