@@ -2,8 +2,8 @@
  **
  ** sngrep - SIP Messages flow viewer
  **
- ** Copyright (C) 2013-2016 Ivan Alonso (Kaian)
- ** Copyright (C) 2013-2016 Irontec SL. All rights reserved.
+ ** Copyright (C) 2013-2018 Ivan Alonso (Kaian)
+ ** Copyright (C) 2013-2018 Irontec SL. All rights reserved.
  **
  ** This program is free software: you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -136,11 +136,29 @@ call_flow_info(ui_t *ui)
 bool
 call_flow_redraw(ui_t *ui)
 {
+    int maxx, maxy;
+
     // Get panel information
     call_flow_info_t *info = call_flow_info(ui);
+    // Get current screen dimensions
+    getmaxyx(stdscr, maxy, maxx);
+
+    // Change the main window size
+    wresize(ui->win, maxy, maxx);
+
+    // Store new size
+    ui->width = maxx;
+    ui->height = maxy;
+
+    // Calculate available printable area
+    wresize(info->flow_win, maxy - 6, maxx);
+
+    // Force flow redraw
+    call_flow_draw(ui);
 
     // Check if any of the group has changed
-    return call_group_has_changed(info->group);
+    // return call_group_has_changed(info->group);
+    return 0;
 }
 
 int
@@ -291,11 +309,13 @@ call_flow_draw_columns(ui_t *ui)
         }
 
         if (setting_enabled(SETTING_CF_SPLITCALLID) || !column->addr.port) {
-            sprintf(coltext, "%s", column->alias);
+            snprintf(coltext, MAX_SETTING_LEN, "%s", column->alias);
         } else if (setting_enabled(SETTING_DISPLAY_ALIAS)) {
-            sprintf(coltext, "%s:%u", column->alias, column->addr.port);
+            snprintf(coltext, MAX_SETTING_LEN, "%.*s:%u",
+                MAX_SETTING_LEN - 7, column->alias, column->addr.port);
         } else {
-            sprintf(coltext, "%s:%u", column->addr.ip, column->addr.port);
+            snprintf(coltext, MAX_SETTING_LEN, "%.*s:%u",
+                MAX_SETTING_LEN - 7, column->addr.ip, column->addr.port);
         }
 
         mvwprintw(ui->win, 2, 10 + 30 * column->colpos + (22 - strlen(coltext)) / 2, "%s", coltext);
@@ -1144,6 +1164,10 @@ call_flow_handle_key(ui_t *ui, int key)
                 call_flow_set_group(info->group);
                 break;
             case ACTION_SAVE:
+                if (capture_sources_count() > 1) {
+                    dialog_run("Saving is not possible when multiple input sources are specified.");
+                    break;
+                }
                 next_ui = ui_create_panel(PANEL_SAVE);
                 save_set_group(next_ui, info->group);
                 save_set_msg(next_ui,
