@@ -2,8 +2,8 @@
  **
  ** sngrep - SIP Messages flow viewer
  **
- ** Copyright (C) 2013-2017 Ivan Alonso (Kaian)
- ** Copyright (C) 2013-2017 Irontec SL. All rights reserved.
+ ** Copyright (C) 2013-2018 Ivan Alonso (Kaian)
+ ** Copyright (C) 2013-2018 Irontec SL. All rights reserved.
  **
  ** This program is free software: you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -655,6 +655,10 @@ call_list_handle_key(ui_t *ui, int key)
                 ui_create_panel(PANEL_STATS);
                 break;
             case ACTION_SAVE:
+                if (capture_sources_count() > 1) {
+                    dialog_run("Saving is not possible when multiple input sources are specified.");
+                    break;
+                }
                 next_ui = ui_create_panel(PANEL_SAVE);
                 save_set_group(next_ui, info->group);
                 break;
@@ -736,7 +740,7 @@ int
 call_list_handle_form_key(ui_t *ui, int key)
 {
     int field_idx;
-    char dfilter[256];
+    char dfilter[COLS];
     int action = -1;
 
     // Get panel information
