@@ -2,8 +2,8 @@
  **
  ** sngrep - SIP Messages flow viewer
  **
- ** Copyright (C) 2013-2017 Ivan Alonso (Kaian)
- ** Copyright (C) 2013-2017 Irontec SL. All rights reserved.
+ ** Copyright (C) 2013-2018 Ivan Alonso (Kaian)
+ ** Copyright (C) 2013-2018 Irontec SL. All rights reserved.
  **
  ** This program is free software: you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -68,14 +68,10 @@ ncurses_init()
 {
     int bg, fg;
     const char *term;
-    FILE *fstdin;
 
     // Set Locale
     setlocale(LC_CTYPE, "");
 
-    // Allow reading from stdin
-    fstdin = freopen("/dev/tty", "r", stdin);
-
     // Initialize curses
     if (!initscr()) {
         fprintf(stderr, "Unable to initialize ncurses mode.\n");
