@@ -2,8 +2,8 @@
  **
  ** sngrep - SIP Messages flow viewer
  **
- ** Copyright (C) 2013-2016 Ivan Alonso (Kaian)
- ** Copyright (C) 2013-2016 Irontec SL. All rights reserved.
+ ** Copyright (C) 2013-2018 Ivan Alonso (Kaian)
+ ** Copyright (C) 2013-2018 Irontec SL. All rights reserved.
  **
  ** This program is free software: you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -82,7 +82,10 @@ enum setting_id {
     SETTING_CAPTURE_LIMIT,
     SETTING_CAPTURE_DEVICE,
     SETTING_CAPTURE_OUTFILE,
+#if defined(WITH_GNUTLS) || defined(WITH_OPENSSL)
     SETTING_CAPTURE_KEYFILE,
+    SETTING_CAPTURE_TLSSERVER,
+#endif
     SETTING_CAPTURE_RTP,
     SETTING_CAPTURE_STORAGE,
     SETTING_CAPTURE_ROTATE,
